@@ -13,8 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import datetime
-import mock
-import six
+from unittest import mock
 
 from barbican.model import models
 from barbican.model import repositories
@@ -411,10 +410,9 @@ class WhenUsingTaskServer(database_utils.RepositoryTestCase):
 
         self.assertEqual(models.States.ERROR, order_result.status)
         self.assertEqual(
-            six.u(
-                'Process TypeOrder failure seen - '
-                'please contact site administrator.'),
+            ('Process TypeOrder failure seen - '
+             'please contact site administrator.'),
             order_result.error_reason)
         self.assertEqual(
-            six.u('500'),
+            '500',
             order_result.error_status_code)
